.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`core.prefilter`
=============================
.. automodule:: IPython.core.prefilter

.. currentmodule:: IPython.core.prefilter

16 Classes
----------

.. autoclass:: PrefilterError
  :members:
  :show-inheritance:

.. autoclass:: PrefilterManager
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: PrefilterTransformer
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: PrefilterChecker
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: EmacsChecker
  :members:
  :show-inheritance:

.. autoclass:: MacroChecker
  :members:
  :show-inheritance:

.. autoclass:: IPyAutocallChecker
  :members:
  :show-inheritance:

.. autoclass:: AssignmentChecker
  :members:
  :show-inheritance:

.. autoclass:: AutoMagicChecker
  :members:
  :show-inheritance:

.. autoclass:: PythonOpsChecker
  :members:
  :show-inheritance:

.. autoclass:: AutocallChecker
  :members:
  :show-inheritance:

.. autoclass:: PrefilterHandler
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: MacroHandler
  :members:
  :show-inheritance:

.. autoclass:: MagicHandler
  :members:
  :show-inheritance:

.. autoclass:: AutoHandler
  :members:
  :show-inheritance:

.. autoclass:: EmacsHandler
  :members:
  :show-inheritance:

1 Function
----------

.. autofunction:: IPython.core.prefilter.is_shadowed

